@@ -111,7 +111,7 @@ def trx_encrypt(
     return send_trx_obj
 
 
-def trx_decrypt(aes_key: bytes, encrypted_trx: dict):
+def trx_decrypt(aes_key: bytes, encrypted_trx: Dict):
     """trx decrypt"""
     # pylint: disable=W,E,R
     data = encrypted_trx.get("Data")
@@ -148,7 +148,7 @@ def pack_content_param(
     reverse: bool = False,
     include_start_trx: bool = False,
     senders=None,
-) -> dict[str, str]:
+) -> Dict[str, str]:
     """pack content param"""
     params = {
         "group_id": group_id,
@@ -171,3 +171,17 @@ def pack_content_param(
     }
 
     return send_param
+
+
+def pack_appconfig_param(
+    aes_key: bytes,
+    group_id: str,
+):
+    obj = {"GroupId": group_id}
+    obj_bytes = json.dumps(reqobj).encode()
+    obj_encrypted = aes_encrypt(aes_key, obj_bytes)
+    param = {
+        "Req": base64.b64encode(obj_encrypted).decode(),
+        "ReqType": "appconfig_listlist",
+    }
+    return param
